@@ -6,9 +6,9 @@ import os
 from botocore.client import Config
 from botocore.exceptions import ClientError
 
-def get_minio_url(url: str, bucket: str, key: str) -> str:
+def get_minio_url(netloc: str, bucket: str, key: str) -> str:
     '''Returns location of given resource in minio once it is saved'''
-    return url + "/" + bucket + "/" + key
+    return netloc + "/" + bucket + "/" + key
 
 
 def get_s3_client(url: str, minio_user: str, minio_pwd: str) -> boto3.client:
@@ -21,25 +21,25 @@ def get_s3_client(url: str, minio_user: str, minio_pwd: str) -> boto3.client:
     )
 
 
-def download_from_minio(url: str, bucket: str, key: str, filepath: str, minio_user: str, minio_pwd: str) -> None:
+def download_from_minio(netloc: str, bucket: str, key: str, filepath: str, minio_user: str, minio_pwd: str) -> None:
     logging.info("Downloading from minio")
-    s3 = get_s3_client(url, minio_user, minio_pwd)
+    s3 = get_s3_client(netloc, minio_user, minio_pwd)
     try:
         s3.download_file(bucket, key, filepath)
         logging.info(
-            f"Resource downloaded from minio at {get_minio_url(url, bucket, key)}"
+            f"Resource downloaded from minio at {get_minio_url(netloc, bucket, key)}"
         )
     except ClientError as e:
         logging.error(e)
 
 
-def upload_to_minio(url: str, bucket: str, key: str, filepath: str, minio_user: str, minio_pwd: str) -> None:
+def upload_to_minio(netloc: str, bucket: str, key: str, filepath: str, minio_user: str, minio_pwd: str) -> None:
     logging.info("Saving to minio")
-    s3 = get_s3_client(url, minio_user, minio_pwd)
+    s3 = get_s3_client(netloc, minio_user, minio_pwd)
     try:
         s3.upload_file(filepath, bucket, key)
         logging.info(
-            f"Resource saved into minio at {get_minio_url(url, bucket, key)}"
+            f"Resource saved into minio at {get_minio_url(netloc, bucket, key)}"
         )
     except ClientError as e:
-        logging.error(e)
\ No newline at end of file
+        logging.error(e)
