@@ -59,7 +59,9 @@ def get_example(format: str) -> str:
         'departement': 'Ain',
         'email': 'example@example.com',
         'insee_ape700': '0130Z',
-        'iso_country_code': 'FR',
+        'iso_country_code_alpha2': 'FR',
+        'iso_country_code_alpha3': 'FRA',
+        'iso_country_code_numeric': 250,
         'jour_de_la_semaine': 'lundi',
         'json_geojson': '{"type": "Point", "coordinates": [0, 0]}',
         'latitude': 42.42,
